@@ -12,7 +12,7 @@ use feature ();
 package Zydeco;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.604';
+our $VERSION   = '0.605';
 
 use Keyword::Simple ();
 use PPR;
@@ -2322,7 +2322,7 @@ sub _include {
 #{
 #	package Zydeco::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.604';
+#	our $VERSION   = '0.605';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -2333,7 +2333,7 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.604';
+#	our $VERSION   = '0.605';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -2346,12 +2346,12 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.604';
+#	our $VERSION   = '0.605';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	
 #	package Zydeco::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.604';
+#	our $VERSION   = '0.605';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2365,7 +2365,7 @@ sub _include {
 #
 #	package Zydeco::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.604';
+#	our $VERSION   = '0.605';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2394,7 +2394,7 @@ sub anonymous_package {
 	
 	require MooX::Press;
 	my $method = "make_$kind";
-	MooX::Press->$method("::$qname", %opts, %$package_dfn);
+	MooX::Press->$method(MooX::Press::make_absolute_package_name($qname), %opts, %$package_dfn);
 	
 	require Module::Runtime;
 	$INC{Module::Runtime::module_notional_filename($qname)} = __FILE__;
@@ -2409,7 +2409,7 @@ sub anonymous_generator {
 	
 	require MooX::Press;
 	my $method = "make_$kind\_generator";
-	MooX::Press->$method("::$qname", %opts, generator => $callback);
+	MooX::Press->$method(MooX::Press::make_absolute_package_name($qname), %opts, generator => $callback);
 	
 	require Module::Runtime;
 	$INC{Module::Runtime::module_notional_filename($qname)} = __FILE__;
